%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
% This code demonstrate the usage of depth data reconstruction algorithm 
% (ADMM algorithm) using single wavelet dictionary.    
%       
% Regarding the detailed information, please refer to our paper:
% Lee-Kang Liu, Stanley H. Chan and Truong Q. Nguyen, "Depth Reconstruction
% from Sparse Samples: Representation, Algorithm and Sampling"
%
% last modfied: 11/06/2014
% Lee-Kang (Lester) Liu and Stanley Chan
% Copyright 2014
% University of California, San Diego
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all
clear all
clc
   
    % access disparity data
    c      = cd('.\data');
    gt_x0  = im2double(imread('Aloe_disp1_512.png'));
    x0     = gt_x0;
    [rows cols] = size(x0);
    cd(c);

    % Initialize parameters
    param.wname            = 'db2';       % types of wavelet function
    param.wlevel           = 2;           % number of levels for wavelet transform
    param.lambda1          = 4e-5;        % regulization parameter for L1_Wavelet term
    param.beta             = 2e-3;        % regulization parameter for totalvariation term
    param.max_itr          = 400;         % maximum iteration for reconstruction
    param.tol              = 1e-5;        % tolerance for stop condition
    param.disp_relchg      = 1;           % display the relative change during process  
    param.disp_img         = 1;           % display image during process
    % Define Sampling Rate (0~1)
    sp = 0.1;  
    
    disp('--- Running Depth Reconstruction Algorithm ---');
    disp(' Dictionary Type : Single Wavelet Dictionary ');
     
    % uniformly random sampling map generation
    S        = (rand(rows, cols)<=sp);
    b = S.*x0;
    
    % ADMM using wavelet dictionary
    xout = ADMM_WT(S,b,param);
    
    % Estimate the Mean Square Error
    MSE = mean(((xout(:)-x0(:)).^2));
    
    
    disp('--- Dense Disparity Map is Reconstructed ---');
    disp(sprintf(' (1). Percentage of uniformly random samples : %2.1f%% \n (2). Mean Square Error (MSE) is : %0.5g. ',100*sp,MSE));