%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
% This code demonstrate the usage of depth data reconstruction algorithm 
% (ADMM algorithm) using combined dictionary.    
%       
% Regarding the detailed information, please refer to our paper:
% Lee-Kang Liu, Stanley H. Chan and Truong Q. Nguyen, "Depth Reconstruction
% from Sparse Samples: Representation, Algorithm and Sampling"
%
% last modfied: 11/06/2014
% Lee-Kang (Lester) Liu and Stanley Chan
% Copyright 2014
% University of California, San Diego
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all
clear all
clc

% access disparity data
c=cd('.\data\');
gt_x0  = im2double(imread('Aloe_disp1_512.png'));
x0 = gt_x0;
[rows cols] = size(x0);
cd(c);

    
        % Initialize parameters
        WTCTparam.wname            = 'db2';                % types of wavelet function
        WTCTparam.wlevel           = 2;                    % number of levels for wavelet transform
        WTCTparam.nlev_SD          = [5 6];                % directional filter partition numbers
        WTCTparam.smooth_func      = @rcos;                % smooth function for Lacian Pyramid
        WTCTparam.Pyr_mode         = 2;                    % reduneancy setting for the transformed coefficients
        WTCTparam.dfilt            = '9-7';                % 9-7 bior filter for directional filtering
        WTCTparam.lambda1          = 4e-5;                 % regularization parameter for L1_Wavelet term
        WTCTparam.lambda2          = 2e-4;                 % regularization parameter for L1_Contourlet term
        WTCTparam.beta             = 2e-3;                 % regularization parameter for totalvariation term
        WTCTparam.max_itr          = 400;                  % maximum iteration for reconstruction
        WTCTparam.tol              = 1e-5;                 % tolerance for stop condition
        WTCTparam.disp_relchg      = 1;                    % display the relative change during process  
        WTCTparam.disp_img         = 1;                    % display image during process        
         % Define Sampling Rate (0~1)
        sp = 0.1;  
 
    disp('--- Running Depth Reconstruction Algorithm ---');
    disp(' Dictionary Type : Combined Dictionary ');
    
        % Set contourlet transform toolbox path
        addpath(genpath('ContourletSD\'));
         
        % uniformly random sampling map generation
        S        = (rand(rows, cols)<=sp);
        b        = S.*x0;
                
        % main algorithm for dense disparity reconstruction
        xout = ADMM_WT_CT(S,b,WTCTparam);
                
        MSE = mean(((xout(:)-x0(:)).^2));
        
 disp('--- Dense Disparity Map is Reconstructed ---');
 disp(sprintf(' (1). Percentage of uniformly random samples : %2.1f%% \n (2). Mean Square Error (MSE) is : %0.5g. ',100*sp,MSE));    

