%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
% This code demonstrates the application for dense disparity estimation
% using the proposed 2-Stage algorithm. In this application, we assume that two
% view images are known, and there exists a disparity estimation algorithm
% for estimating disparities at the ''targeted'' sampling locations.
%
%
%       
% Regarding the detailed information, please refer to our paper:
% Lee-Kang Liu, Stanley H. Chan and Truong Q. Nguyen, "Depth Reconstruction
% from Sparse Samples: Representation, Algorithm and Sampling"
%
% last modfied: 11/07/2014
% Lee-Kang (Lester) Liu and Stanley Chan
% Copyright 2014
% University of California, San Diego
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



clear all
close all
clc


  % access disparity data
    c      = cd('.\data');
    gt_x0  = im2double(imread('Newspaper_Dense_Estimation.png'));
    y0     = im2double(imread('Newspaper_Left.png'));
    x0     = gt_x0;
    [rows cols] = size(x0);
    cd(c);
  
   w       = 5;        % bilateral filter half-width
   sigma   = [10 0.1]; % bilateral filter standard deviations
   y0_bflt = rgb2gray(bfilter2(y0,w,sigma));   
    
    % total number of pixels
    n  = rows*cols;
   
    % sampling ratio
    sp = 0.1;

     disp('--- Running Demonstration for Dense Disparity Estimation ---');
     disp(' A. Reconstruction function : ');
     disp('     Multiscale ADMM for Combined Dictionary ');
     disp(' B. Inferred information for Oracle Random Sampling :');
     disp('     Sum of magnitude of PCA coefficients  ');



% ------------ 2 Stage with PCA -------------------
    % 1st Stage
    S_pilot      = zeros(rows,cols);
    S_pilot      = Oracle_Random_Sampling_with_PCA( y0_bflt, 0.5*sp, S_pilot);
       b         = S_pilot.*x0;
     xout_pilot  = ADMM_outer(S_pilot,b);

    % 2nd Stage  
     S           = Oracle_Random_Sampling_with_PCA( xout_pilot, 0.5*sp, S_pilot);
     b           = S.*x0;
     xout        = ADMM_outer(S,b);

     
     MSE = mean(((xout(:)-x0(:)).^2));
     figure; imshow(xout);

     disp('--- Dense Disparity Map is Reconstructed ---');
     disp(sprintf('  Percentage of Random samples %2.1f%% \n',100*mean(double(S(:)))));                                   
