%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
% This code demonstrates the proposed two stage sampling scheme using the 
% function 
%
%      S  = Oracle_Random_Sampling_PCA(x0, sp) 
%
% The function performs the proposed Oracle Random Sampling Scheme using 
% sum of magnitude of PCA coefficients as inferred information. 
%       
% Regarding the detailed information, please refer to our paper:
% Lee-Kang Liu, Stanley H. Chan and Truong Q. Nguyen, "Depth Reconstruction
% from Sparse Samples: Representation, Algorithm and Sampling"
%
% last modfied: 02/06/2015
% Lee-Kang (Lester) Liu and Stanley Chan
% Copyright 2014
% University of California, San Diego
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



clear all
close all
clc


  % access disparity data
    c      = cd('.\data');
    gt_x0  = im2double(imread('Aloe_disp1_512.png'));
    x0     = gt_x0;
    [rows cols] = size(x0);
    cd(c);

    % total number of pixels
    n  = rows*cols;
   
    % sampling ratio
    sp = 0.1;

     disp('--- Running 2 Stage Sampling Scheme ---');
     disp(' A. Reconstruction function : ');
     disp('     Multiscale ADMM for Combined Dictionary ');
     disp(' B. Inferred information for Oracle Random Sampling :');
     disp('     Sum of magnitude of PCA coefficients  ');



% ------------ 2 Stage with PCA -------------------
    % 1st Stage
    S_pilot      = (rand(rows,cols)<=sp*0.5);
       b         = S_pilot.*x0;
     xout_pilot  = ADMM_outer(S_pilot,b);

    % 2nd Stage  
     S           = Oracle_Random_Sampling_with_PCA( xout_pilot, 0.5*sp, S_pilot);
     b           = S.*x0;
     xout        = ADMM_outer(S,b);

     
     MSE = mean(((xout(:)-x0(:)).^2));
     figure; imshow(xout);

     disp('--- Dense Disparity Map is Reconstructed ---');
     disp(sprintf(' (1). Percentage of Random samples %2.1f%% \n (2). Mean Square Error (MSE) is : %0.5g. ',100*mean(double(S(:))),MSE));                                   
